@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: Auxiliary.h 2661 2007-11-16 16:42:38Z svn $
  *****************************************************************************/
 
 #ifndef AUXILIARY_H
@@ -41,7 +41,14 @@
 #include "apr_time.h"
 #include "apr_shm.h"
 
-
+/**
+ * 文字列を URL エンコードします．
+ *
+ * @param[in] pool プール
+ * @param[in] str 文字列
+ * @return URL エンコードされた文字列
+ */
+const char *rfc2396_encode(apr_pool_t *pool, const char* str);
 /**
  * アトミック関数を初期化します．
  *
