@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.h 2576 2007-10-13 19:18:17Z svn $
+ * $Id: DownloadFlowController.h 2616 2007-10-29 14:50:31Z svn $
  *****************************************************************************/
 
 #ifndef DOWNLOAD_FLOW_CONTROLLER_H
@@ -81,22 +81,8 @@ class DownloadSession: public Uncopyable
 {
 public:
     DownloadSession(DownloadFlowController *flow_controller,
-                    apr_sockaddr_t *sockaddr)
-      : flow_controller_(flow_controller),
-        sockaddr_(sockaddr)
-    {
-        is_valid_ = flow_controller_->add_session(sockaddr_);
-
-        if (!is_valid_) {
-            apr_sleep(apr_time_from_sec(DOWNLOAD_BUSY_SLEEP_SEC));
-        }
-    };
-    ~DownloadSession()
-    {
-        if (is_valid_) {
-            flow_controller_->remove_session(sockaddr_);
-        }
-    };
+                    apr_sockaddr_t *sockaddr);
+    ~DownloadSession();
     bool is_valid()
     {
         return is_valid_;
