@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageDigest5.h 2035 2006-11-23 16:14:21Z svn $
+ * $Id: MessageDigest5.h 2296 2006-12-24 02:58:57Z svn $
  *****************************************************************************/
 
 #ifndef MESSAGE_DIGEST5_H
@@ -36,7 +36,6 @@
 
 #include "Uncopyable.h"
 
-using namespace std;
 
 /**
  * @brief MD5 を計算するクラス．
@@ -45,43 +44,31 @@ class MessageDigest5: public Uncopyable
 {
 public:
     MessageDigest5();
-    void update(const apr_byte_t *input, apr_size_t size)
-#ifndef DEBUG
-    throw()
-#endif
-        ;
-    void finish()
-#ifndef DEBUG
-    throw()
-#endif
-        ;
-    const char *c_str()
-#ifndef DEBUG
-    throw()
-#endif
-        ;
+    void update(const apr_byte_t *input, apr_size_t size);
+    void finish();
+    const char *c_str();
 
 private:
     /** 最後のパディング用データ（0x8000_0000_0000_0000） */
     static const apr_byte_t PADDING[64];
 
-    apr_uint32_t calc_f(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z) throw();
-    apr_uint32_t calc_g(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z) throw();
-    apr_uint32_t calc_h(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z) throw();
-    apr_uint32_t calc_i(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z) throw();
-    apr_uint32_t rotl(apr_uint32_t value, apr_uint32_t shift) throw();
+    apr_uint32_t calc_f(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z);
+    apr_uint32_t calc_g(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z);
+    apr_uint32_t calc_h(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z);
+    apr_uint32_t calc_i(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z);
+    apr_uint32_t rotl(apr_uint32_t value, apr_uint32_t shift);
     apr_uint32_t round1(apr_uint32_t a, apr_uint32_t b, apr_uint32_t c,
                         apr_uint32_t d, apr_uint32_t x, apr_uint32_t s,
-                        apr_uint32_t t) throw();
+                        apr_uint32_t t);
     apr_uint32_t round2(apr_uint32_t a, apr_uint32_t b, apr_uint32_t c,
                         apr_uint32_t d, apr_uint32_t x, apr_uint32_t s,
-                        apr_uint32_t t) throw();
+                        apr_uint32_t t);
     apr_uint32_t round3(apr_uint32_t a, apr_uint32_t b, apr_uint32_t c,
                         apr_uint32_t d, apr_uint32_t x, apr_uint32_t s,
-                        apr_uint32_t t) throw();
+                        apr_uint32_t t);
     apr_uint32_t round4(apr_uint32_t a, apr_uint32_t b, apr_uint32_t c,
                         apr_uint32_t d, apr_uint32_t x, apr_uint32_t s,
-                        apr_uint32_t t) throw();
+                        apr_uint32_t t);
     /**
      * リトルエンディアンのバイト列を apr_uint32_t の配列に変換します．
      *
@@ -90,7 +77,7 @@ private:
      * @param[in] bytes バイト列
      * @param[out] ints apr_uint32_t の配列
      */
-    void byte2int(const apr_byte_t *bytes, apr_uint32_t *ints) throw();
+    void byte2int(const apr_byte_t *bytes, apr_uint32_t *ints);
     /**
      * apr_uint32_t の配列をリトルエンディアンのバイト列に変換します．
      *
@@ -99,10 +86,10 @@ private:
      * @param[out] bytes バイト列
      */
     void int2byte(const apr_uint32_t *ints, apr_size_t size,
-                  apr_byte_t *bytes) throw();
-    void process(const apr_byte_t block[64]) throw();
+                  apr_byte_t *bytes);
+    void process(const apr_byte_t block[64]);
     /** ハッシュ値を算出します． */
-    void create_digest() throw();
+    void create_digest();
 
     apr_uint32_t state_[4];
     /** 入力の bit サイズ */
