@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2604 2007-10-26 13:58:10Z svn $
+ * $Id: UploadItem.h 2619 2007-11-02 16:25:07Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -219,6 +219,10 @@ public:
                                     const char *comment="",
                                     const char *code_pat="",
                                     bool is_need_validate=true);
+    static int cmp_file_name(const UploadItem *a, const UploadItem *b);
+    static int cmp_file_size(const UploadItem *a, const UploadItem *b);
+    static int cmp_file_mime(const UploadItem *a, const UploadItem *b);
+    static int cmp_comment(const UploadItem *a, const UploadItem *b);
     static int cmp_download_count(const UploadItem *a, const UploadItem *b);
 
 private:
