@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 2604 2007-10-26 13:58:10Z svn $
+ * $Id: UploadItem.cpp 2620 2007-11-02 16:36:07Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItem.cpp 2604 2007-10-26 13:58:10Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItem.cpp 2620 2007-11-02 16:36:07Z svn $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -126,10 +126,52 @@ UploadItem *UploadItem::get_instance(apr_pool_t *pool, apr_size_t item_id,
                         is_need_validate);
 }
 
+int UploadItem::cmp_file_name(const UploadItem *a, const UploadItem *b)
+{
+    return strcmp(b->get_file_name(), a->get_file_name());
+}
+
+int UploadItem::cmp_file_size(const UploadItem *a, const UploadItem *b)
+{
+    apr_uint64_t a_file_size;
+    apr_uint64_t b_file_size;
+
+    a_file_size = a->get_file_size();
+    b_file_size = b->get_file_size();
+
+    if (b_file_size > a_file_size) {
+        return 1;
+    } else if (b_file_size == a_file_size) {
+        return 0;
+    } else {
+        return -1;
+    }
+}
+
+int UploadItem::cmp_file_mime(const UploadItem *a, const UploadItem *b)
+{
+    return strcmp(b->get_file_mime(), a->get_file_mime());
+}
+int UploadItem::cmp_comment(const UploadItem *a, const UploadItem *b)
+{
+    return strcmp(b->get_comment(), a->get_comment());
+}
+
 int UploadItem::cmp_download_count(const UploadItem *a, const UploadItem *b)
 {
-    return static_cast<int>(b->get_download_count()) -
-        static_cast<int>(a->get_download_count());
+    apr_atomic_t a_download_count;
+    apr_atomic_t b_download_count;
+
+    a_download_count = a->get_download_count();
+    b_download_count = b->get_download_count();
+
+    if (b_download_count > a_download_count) {
+        return 1;
+    } else if (b_download_count == a_download_count) {
+        return 0;
+    } else {
+        return -1;
+    }
 }
 
 
