@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2623 2007-11-05 16:23:18Z svn $
+ * $Id: uploader_handler.cpp 2662 2007-11-16 16:58:55Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2623 2007-11-05 16:23:18Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2662 2007-11-16 16:58:55Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -737,6 +737,125 @@ static int input_pass(typename Response::Handle *r, UploaderConfig *config,
     return OK;
 }
 
+template<class Response>
+static int download_set_header(typename Response::Handle *r, UploadItem *uitem)
+{
+#ifdef UPLOADER_TYPE_APACHE
+        Response::set_content_type(r);
+#else
+        Response::set_content_type(r, uitem->get_file_mime());
+#endif
+
+#ifndef DEBUG
+        Response::set_modified_time(r, uitem->get_mtime());
+        Response::set_last_modified(r, uitem->get_mtime());
+
+        int status;
+        if ((status = Response::is_meets_condition(r)) != OK) {
+            return status;
+        }
+#endif
+
+        Response::set_accept_ranges(r);
+
+        return OK;
+}
+
+template<class Response>
+static int download_impl(typename Response::Handle *r, UploadItem *uitem,
+                         apr_file_t *item_file, const char *mode)
+{
+    int status;
+
+    status = download_set_header<Response>(r, uitem);
+    if (status != OK) {
+        Response::header_end(r);
+        return status;
+    }
+
+    if (Response::is_head_method(r)) {
+        Response::header_end(r);
+        return OK;
+    }
+
+    Response::set_content_disposition(r, mode);
+    Response::header_end(r);
+
+    Response::set_env(r, "uploader_download", "");
+    Response::set_env(r, "uploader_item_id",
+                      apr_psprintf(r->pool, "%u", uitem->get_id()));
+
+    // better to use ap_internal_fast_redirect for Apache
+    Response::Writer::sendfile(r, item_file, uitem->get_file_size());
+
+    return OK;
+}
+
+template<class Response>
+static int download_prep(typename Response::Handle *r, UploaderConfig *config,
+                         UploadItem *uitem)
+{
+    const char *file_name;
+    int status;
+
+    if (Response::is_head_method(r)) {
+        status = download_set_header<Response>(r, uitem);
+
+        Response::header_end(r);
+        if (status != OK) {
+            return status;
+        } else {
+            return OK;
+        }
+    }
+
+#ifdef NUMNAME
+    file_name = apr_psprintf(r->pool, "%s%5" APR_SIZE_T_FMT ".%s",
+                             NUMNAME, uitem->get_index(),
+                             uitem->get_file_ext());
+#else
+    file_name = CharCodeConverter::convert
+        (r->pool, uitem->get_file_name(),
+         CharCodeConverter::DEFAULT_CODE, "utf-8");
+#endif
+
+    typename Response::Writer o(r);
+
+    return redirect<Response>
+        (r, o,
+         apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR,
+                     DOWNLOAD_COMMAND, ARG_SEPARATE_STR,
+                     apr_psprintf(r->pool, "%u", uitem->get_id()),
+                     ARG_SEPARATE_STR, "attach", ARG_SEPARATE_STR,
+                     rfc2396_encode(r->pool, file_name), NULL));
+}
+
+template<class Response>
+static int download_view(typename Response::Handle *r, UploadItem *uitem,
+                         apr_file_t *item_file)
+{
+    int status;
+
+    status = download_set_header<Response>(r, uitem);
+    if (status != OK) {
+        Response::header_end(r);
+        return status;
+    }
+
+    if (Response::is_head_method(r)) {
+        Response::header_end(r);
+        return OK;
+    }
+
+    Response::set_content_disposition(r, "inline");
+    Response::header_end(r);
+
+    // better to use ap_internal_fast_redirect for Apache
+    Response::Writer::sendfile(r, item_file, uitem->get_file_size());
+
+    return OK;
+}
+
 template<class Response>
 static int download(typename Response::Handle *r, UploaderConfig *config,
                     const char *arg, bool is_admin_mode=false)
@@ -758,9 +877,7 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
         UploadItem *uitem;
         const char *download_pass;
         apr_file_t *item_file;
-        const char *open_mode;
-        const char *dispos_encoding;
-        const char *file_name;
+        bool is_view_mode;
 
         if (Response::is_post_method(r)) {
             RequestReader::post_progress_t progress;
@@ -786,6 +903,8 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
         }
 
         uitem = config->get_item_manager()->get_item(r->pool, item_id);
+        is_view_mode = (strlen(get_word(r->pool, &arg,
+                                        ARG_SEPARATE_STR[0])) == 0);
 
         // DL pass のチェック
         if (!is_admin_mode) {
@@ -795,7 +914,12 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
                 if (strlen(download_pass) != 0) {
                     THROW(MESSAGE_DOWNLOAD_PASS_MISMATCH);
                 }
-                return input_pass<Response>(r, config, uitem);
+                if (!is_view_mode &&
+                    (strlen(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])) == 0)) {
+                    return download_prep<Response>(r, config, uitem);
+                } else {
+                    return input_pass<Response>(r, config, uitem);
+                }
             }
         }
 
@@ -818,60 +942,21 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
             r->finfo.filetype = APR_REG;
             r->finfo.size = uitem->get_file_size();
         }
-        Response::set_content_type(r);
-#else
-        Response::set_content_type(r, uitem->get_file_mime());
 #endif
 
-#ifndef DEBUG
-        Response::set_modified_time(r, uitem->get_mtime());
-        Response::set_last_modified(r, uitem->get_mtime());
-
-        int status;
-        if ((status = Response::is_meets_condition(r)) != OK) {
-            Response::header_end(r);
-            return status;
+        if (is_view_mode) {
+            // 表示
+            return download_impl<Response>(r, uitem, item_file, "inline");
+        } else {
+            if (strlen(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])) == 0) {
+                // ファイル名を追加した URL に飛ばす
+                return download_prep<Response>(r, config, uitem);
+            } else {
+                // ダウンロード
+                return download_impl<Response>(r, uitem, item_file,
+                                               "attachment");
+            }
         }
-#endif
-        if (Response::is_head_method(r)) {
-            return OK;
-        }
-
-        Response::set_accept_ranges(r);
-
-        dispos_encoding = get_dispos_encoding(Response::get_user_agent(r));
-
-#ifdef NUMNAME
-        file_name = apr_psprintf(r->pool, "%s%5" APR_SIZE_T_FMT ".%s",
-                                 NUMNAME, uitem->get_index(),
-                                 uitem->get_file_ext());
-#else
-#ifdef CONV_CHAR_CODE
-        file_name = CharCodeConverter::convert
-            (r->pool, uitem->get_file_name(),
-             CharCodeConverter::DEFAULT_CODE, dispos_encoding);
-#else
-        file_name = uitem->get_file_name();
-#endif
-#endif
-
-        // 表示モード or ダウンロードモード
-        open_mode = (strlen(get_word(r->pool, &arg,
-                                     ARG_SEPARATE_STR[0])) == 0)
-            ? "inline" : "attachment";
-        // Content-Disposition
-        Response::set_content_disposition
-            (r,
-             apr_psprintf(r->pool, "%s; filename=\"%s\"", open_mode,
-                          file_name));
-        Response::header_end(r);
-
-        Response::set_env(r, "uploader_download", "");
-        Response::set_env(r, "uploader_item_id",
-                          apr_psprintf(r->pool, "%u", item_id));
-
-        // better to use ap_internal_fast_redirect for Apache
-        Response::Writer::sendfile(r, item_file, uitem->get_file_size());
     } catch(const char *message) {
         return error<Response>(r, config, message);
     }
