@@ -79,14 +79,6 @@ sub make_config {
     $exp->expect(MAKE_TIMEOUT_SEC, $host . '%');
 }
 
-sub cd_src_dir {
-    my $exp = shift;
-    my $host = shift;
-
-    $exp->send('cd src' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, $host . '%');
-}
-
 sub make_check {
     my $exp = shift;
     my $host = shift;
@@ -97,10 +89,13 @@ sub make_check {
     $exp->send('gmake SHELL=$SHELL WITH_COLOR=1' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, $host . '%');
 
-    $exp->send('gmake clean-obj WITH_COLOR=1' . "\n");
+    $exp->send('sudo gmake -f GNUmakefile.apache install SHELL=$SHELL WITH_COLOR=1' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, $host . '%');
 
-    $exp->send('gmake test-run SHELL=$SHELL WITH_COLOR=1' . "\n");
+    $exp->send('gmake -C src clean-obj WITH_COLOR=1' . "\n");
+    $exp->expect(MAKE_TIMEOUT_SEC, $host . '%');
+
+    $exp->send('gmake -C src test-run SHELL=$SHELL WITH_COLOR=1' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, $host . '%');
 }
 
@@ -116,8 +111,6 @@ cd_top_dir($exp, $host);
 svn_update($exp, $host);
 # 
 make_config($exp, $host);
-# ǥ쥯ȥΰư
-cd_src_dir($exp, $host);
 # ѥ
 make_check($exp, $host);
 
